==> ompl_1.5.2+ds1.orig.tar.xz: ompl-1.5.2/demos/Koules/KoulesGoal.h <==
/*********************************************************************
* Software License Agreement (BSD License)
*
*  Copyright (c) 2013, Rice University
*  All rights reserved.
*
*  Redistribution and use in source and binary forms, with or without
*  modification, are permitted provided that the following conditions
*  are met:
*
*   * Redistributions of source code must retain the above copyright
*     notice, this list of conditions and the following disclaimer.
*   * Redistributions in binary form must reproduce the above
*     copyright notice, this list of conditions and the following
*     disclaimer in the documentation and/or other materials provided
*     with the distribution.
*   * Neither the name of the Rice University nor the names of its
*     contributors may be used to endorse or promote products derived
*     from this software without specific prior written permission.
*
*  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
*  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
*  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
*  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
*  COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
*  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
*  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
*  LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
*  CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
*  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
*  ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
*  POSSIBILITY OF SUCH DAMAGE.
*********************************************************************/

/* Author: Beck Chen, Mark Moll */

#ifndef DEMOS_KOULES_GOAL_
#define DEMOS_KOULES_GOAL_

#include <ompl/base/goals/GoalSampleableRegion.h>

// Sampleable goal region for KoulesModel.
class KoulesGoal : public ompl::base::GoalSampleableRegion
{
public:
    KoulesGoal(const ompl::base::SpaceInformationPtr &si)
        : ompl::base::GoalSampleableRegion(si), stateSampler_(si->allocStateSampler())
    {
        threshold_ = 0.01;
    }

    // number of "live" koules plus the shortest distance between any live koule and an edge
    virtual double distanceGoal(const ompl::base::State *st) const;
    // pick a random state where each koule is on the edge of the workspace
    virtual void sampleGoal(ompl::base::State *st) const;
    virtual unsigned int maxSampleCount() const
    {
        return std::numeric_limits<unsigned int>::max();
    }


private:
    mutable ompl::RNG rng_;
    ompl::base::StateSamplerPtr stateSampler_;
};

#endif

==> ompl_1.6.0+ds1.orig.tar.xz: ompl-1.6.0/demos/Koules/KoulesGoal.h <==
/*********************************************************************
* Software License Agreement (BSD License)
*
*  Copyright (c) 2013, Rice University
*  All rights reserved.
*
*  Redistribution and use in source and binary forms, with or without
*  modification, are permitted provided that the following conditions
*  are met:
*
*   * Redistributions of source code must retain the above copyright
*     notice, this list of conditions and the following disclaimer.
*   * Redistributions in binary form must reproduce the above
*     copyright notice, this list of conditions and the following
*     disclaimer in the documentation and/or other materials provided
*     with the distribution.
*   * Neither the name of the Rice University nor the names of its
*     contributors may be used to endorse or promote products derived
*     from this software without specific prior written permission.
*
*  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
*  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
*  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
*  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
*  COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
*  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
*  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
*  LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
*  CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
*  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
*  ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
*  POSSIBILITY OF SUCH DAMAGE.
*********************************************************************/

/* Author: Beck Chen, Mark Moll */

#ifndef DEMOS_KOULES_GOAL_
#define DEMOS_KOULES_GOAL_

#include <ompl/base/goals/GoalSampleableRegion.h>

// Sampleable goal region for KoulesModel.
class KoulesGoal : public ompl::base::GoalSampleableRegion
{
public:
    KoulesGoal(const ompl::base::SpaceInformationPtr &si)
        : ompl::base::GoalSampleableRegion(si), stateSampler_(si->allocStateSampler())
    {
        threshold_ = 0.01;
    }

    // number of "live" koules plus a shortest distance between any live koule and an edge
    virtual double distanceGoal(const ompl::base::State *st) const;
    // pick a random state where each koule is on the edge of the workspace
    virtual void sampleGoal(ompl::base::State *st) const;
    virtual unsigned int maxSampleCount() const
    {
        return std::numeric_limits<unsigned int>::max();
    }


private:
    mutable ompl::RNG rng_;
    ompl::base::StateSamplerPtr stateSampler_;
};

#endif
